@@ -71,12 +71,10 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
     //activates it from the K menu, there's no URL, so the command becomes "kfmclient openURL text/html", which causes
     //kfmclient to attempt to open the URL text/html. Adding this option allows to change the exec line in kfmclient_html
     //to kfmclient --mimetype text/html openURL %u, allowing an easy fix of the bug (see doIt()).
-    //The option is hidden because string freeze forbids to add text visible to the user.
-    QCommandLineOption typeOption{{QStringLiteral("mimetype"), QStringLiteral("t")},
-        QStringLiteral("The mimetype of the URL. Allows Konqueror to determine in advance which component to use, making it start faster."),
-        QStringLiteral("type"), QString()};
-    typeOption.setFlags(QCommandLineOption::HiddenFromHelp);
-    parser.addOption(typeOption);
+    //TODO: remove the old syntax of specifying the mimetype after the URL when building for KF6
+    parser.addOption({{QStringLiteral("mimetype"), QStringLiteral("t")},
+        i18n("The mimetype of the URL. Allows Konqueror to determine in advance which component to use, making it start faster."),
+        i18nc("the name for a the value of an option on the command line help", "type"), QString()});
 
     parser.addPositionalArgument(QStringLiteral("command"), i18n("Command (see --commands)"));
 
@@ -95,10 +93,12 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
                   "            # Opens a window showing 'url'.\n"
                   "            #  'url' may be a relative path\n"
                   "            #   or file name, such as . or subdir/\n"
-                  "            #   If 'url' is omitted, $HOME is used instead.\n\n").toLocal8Bit());
+                  "            #   If 'url' is omitted, the start page is shown.\n\n").toLocal8Bit());
         puts(i18n("            # If 'mimetype' is specified, it will be used to determine the\n"
                   "            #   component that Konqueror should use. For instance, set it to\n"
-                  "            #   text/html for a web page, to make it appear faster\n\n").toLocal8Bit());
+                  "            #   text/html for a web page, to make it appear faster\n"
+                  "            # Note: this way of specifying mimetype is deprecated.\n"
+                  "            #   Please use the --mimetype option\n\n").toLocal8Bit());
 
         puts(i18n("  kfmclient newTab 'url' ['mimetype']\n"
                   "            # Same as above but opens a new tab with 'url' in an existing Konqueror\n"
@@ -301,26 +301,12 @@ bool ClientApp::doIt(const QCommandLineParser &parser)
         checkArgumentCount(argc, 1, 3);
         const bool tempFile = parser.isSet(QStringLiteral("tempfile"));
 
-        QUrl url;
-        //This is a workaround to ensure that, when kfmclient_html is launched from
-        //the Favorites section of the K menu, the starting page is loaded as expected
-        //instead of the home page (it would make more sense to load the starting page
-        //also when no URL is given, but can't do that right now because of string freeze:
-        //the behavior when no URL is given is displayed in the help
-        //Since --mimetype is (for now) an internal option, it's safe to assume that when
-        //that option is set, it means that kfmclient has been called from one of the
-        //kfmclient_* desktop entries.
-        if (parser.isSet(QStringLiteral("mimetype")) && argc == 1) {
+        QUrl url = argc > 1 ? filteredUrl(args.at(1)) : QUrl();
+
+        //If the given URL is empty, show the start page
+        if (url.isEmpty()) {
             KConfigGroup grp = KSharedConfig::openConfig(QStringLiteral("konquerorrc"))->group("UserSettings");
             url = QUrl(grp.readEntry("StartURL", QStringLiteral("konq:konqueror")));
-        } else if (argc > 1) {
-            url = filteredUrl(args.at(1));
-        }
-
-        //If the given URL is empty an "Undocumented error" error page would be displayed.
-        //To avoid this, default to the user's home directory, as if no URL had been given
-        if (url.isEmpty()) {
-            url = QUrl::fromLocalFile(QDir::homePath());
         }
 
         QString mimetype = argc == 3 ? args.at(2) : QString();
