@@ -21,8 +21,6 @@
 #include <KMainWindow>
 #include <KParts/Part>
 #include <KParts/BrowserExtension>
-#include <KParts/TextExtension>
-#include <KParts/HtmlExtension>
 #include <KParts/SelectorInterface>
 #include <KParts/PartActivateEvent>
 #include <KLocalizedString>
@@ -43,6 +41,8 @@
 
 #include "searchbar_debug.h"
 #include <asyncselectorinterface.h>
+#include <htmlextension.h>
+#include <textextension.h>
 
 K_PLUGIN_CLASS_WITH_JSON(SearchBarPlugin, "searchbar.json")
 
@@ -195,7 +195,7 @@ void SearchBarPlugin::startSearch(const QString &search)
     m_lastSearch = search;
 
     if (m_searchMode == FindInThisPage) {
-        KParts::TextExtension *textExt = KParts::TextExtension::childObject(m_part);
+        TextExtension *textExt = TextExtension::childObject(m_part);
         if (textExt) {
             textExt->findText(search, KFind::SearchOptions());
         }
@@ -449,7 +449,7 @@ void SearchBarPlugin::HTMLDocLoaded()
 
     //NOTE: the link below seems to be dead
     // Testcase for this code: http://search.iwsearch.net
-    KParts::HtmlExtension *ext = KParts::HtmlExtension::childObject(m_part);
+    HtmlExtension *ext = HtmlExtension::childObject(m_part);
     KParts::SelectorInterface *selectorInterface = qobject_cast<KParts::SelectorInterface *>(ext);
     AsyncSelectorInterface *asyncIface = qobject_cast<AsyncSelectorInterface*>(ext);
     const QString query(QStringLiteral("head > link[rel=\"search\"][type=\"application/opensearchdescription+xml\"]"));
