@@ -1,23 +1,23 @@
 /*
- * Copyright (c) Martin R. Jones 1996
- * Copyright (c) Bernd Wuebben 1998
- *
- * Copyright (c) Torben Weis 1998
- *     KControl port & modifications
- *
- * Copyright (c) David Faure 1998
- *     End of the KControl port, added 'kfmclient configure' call.
- *
- * Copyright (c) Kalle Dalheimer 2000
- *     New configuration scheme for Java/JavaScript
- *
- * Copyright (c) Daniel Molkentin 2000
- *     Redesign and cleanup
- *
- * Copyright (c) Leo Savernik 2002-2003
- *     Big changes to accommodate per-domain settings
- *
- */
+    SPDX-FileCopyrightText: 1996 Martin R. Jones
+    SPDX-FileCopyrightText: 1998 Bernd Wuebben
+
+    SPDX-FileCopyrightText: 1998 Torben Weis
+    KControl port & modifications
+
+    SPDX-FileCopyrightText: 1998 David Faure
+    End of the KControl port, added 'kfmclient configure' call.
+
+    SPDX-FileCopyrightText: 2000 Kalle Dalheimer
+    New configuration scheme for Java/JavaScript
+
+    SPDX-FileCopyrightText: 2000 Daniel Molkentin
+    Redesign and cleanup
+
+    SPDX-FileCopyrightText: 2002-2003 Leo Savernik
+    Big changes to accommodate per-domain settings
+
+*/
 
 // Own
 #include "javaopts.h"
@@ -32,14 +32,14 @@
 #include <klineedit.h>
 #include <KLocalizedString>
 #include <QHBoxLayout>
-#include <kparts/htmlextension.h>
-#include <kparts/htmlsettingsinterface.h>
 #include <kconfiggroup.h>
 #include <kpluralhandlingspinbox.h>
 
 // Local
 #include "htmlopts.h"
 #include "policydlg.h"
+#include <htmlextension.h>
+#include <htmlsettingsinterface.h>
 
 // == class JavaPolicies =====
 
@@ -302,14 +302,14 @@ void JavaDomainListView::updateDomainListLegacy(const QStringList &domainConfig)
     const QStringList::ConstIterator itEnd = domainConfig.end();
     for (QStringList::ConstIterator it = domainConfig.begin(); it != itEnd; ++it) {
         QString domain;
-        KParts::HtmlSettingsInterface::JavaScriptAdvice javaAdvice;
-        KParts::HtmlSettingsInterface::JavaScriptAdvice javaScriptAdvice;
-        KParts::HtmlSettingsInterface::splitDomainAdvice(*it, domain, javaAdvice, javaScriptAdvice);
-        if (javaAdvice != KParts::HtmlSettingsInterface::JavaScriptDunno) {
+        HtmlSettingsInterface::JavaScriptAdvice javaAdvice;
+        HtmlSettingsInterface::JavaScriptAdvice javaScriptAdvice;
+        HtmlSettingsInterface::splitDomainAdvice(*it, domain, javaAdvice, javaScriptAdvice);
+        if (javaAdvice != HtmlSettingsInterface::JavaScriptDunno) {
             QTreeWidgetItem *index = new QTreeWidgetItem(domainSpecificLV, QStringList() << domain <<
-                    i18n(KParts::HtmlSettingsInterface::javascriptAdviceToText(javaAdvice)));
+                    i18n(HtmlSettingsInterface::javascriptAdviceToText(javaAdvice)));
             pol.setDomain(domain);
-            pol.setFeatureEnabled(javaAdvice != KParts::HtmlSettingsInterface::JavaScriptReject);
+            pol.setFeatureEnabled(javaAdvice != HtmlSettingsInterface::JavaScriptReject);
             domainPolicies[index] = new JavaPolicies(pol);
         }
     }
