@@ -21,6 +21,9 @@
 #include "konqmainwindowfactory.h"
 #include "konqmisc.h"
 #include <config-konqueror.h>
+#include "implementations/konqbrowser.h"
+
+#include "interfaces/browser.h"
 
 #include <QDBusConnection>
 #include <QDBusMessage>
@@ -30,7 +33,12 @@
 #include <QProcess>
 #include <QDirIterator>
 #include <QTextStream>
+
+#if QT_VERSION_MAJOR < 6
 #include <QX11Info>
+#else
+#include <QtGui/private/qtx11extras_p.h>
+#endif
 
 #include <KCrash>
 #include <KLocalizedString>
@@ -49,6 +57,8 @@
 #include <KActivities/Consumer>
 #endif
 
+using namespace KonqInterfaces;
+
 #ifdef KActivities_FOUND
 QString KonquerorApplication::currentActivity()
 {
@@ -58,7 +68,7 @@ QString KonquerorApplication::currentActivity()
 #endif
 
 KonquerorApplication::KonquerorApplication(int &argc, char **argv)
-    : QApplication(argc, argv)
+    : QApplication(argc, argv), m_browser(nullptr)
 {
     // enable high dpi support
     setAttribute(Qt::AA_UseHighDpiPixmaps, true);
@@ -114,6 +124,7 @@ void KonquerorApplication::slotReparseConfiguration()
 {
     KSharedConfig::openConfig()->reparseConfiguration();
     KonqFMSettings::reparseConfiguration();
+    m_browser->applyConfiguration();
 
     QList<KonqMainWindow *> *mainWindows = KonqMainWindow::mainWindowList();
     if (mainWindows) {
@@ -121,6 +132,7 @@ void KonquerorApplication::slotReparseConfiguration()
             window->reparseConfiguration();
         }
     }
+
     emit configurationChanged();
 }
 
@@ -144,7 +156,7 @@ void KonquerorApplication::setupAboutData()
     KAboutData m_aboutData("konqueror", i18n("Konqueror"), KONQUEROR_VERSION);
     m_aboutData.setShortDescription(i18n("Web browser, file manager and document viewer."));
     m_aboutData.addLicense(KAboutLicense::GPL_V2);
-    m_aboutData.setCopyrightStatement(i18n("(C) 1999-2016, The Konqueror developers"));
+    m_aboutData.setCopyrightStatement(i18n("(C) 1999-2023, The Konqueror developers"));
     m_aboutData.setHomepage("https://apps.kde.org/konqueror");
 
     m_aboutData.addAuthor(i18n("Stefano Crocco"), i18n("Current maintainer"), "stefano.crocco@alice.it");
@@ -185,7 +197,11 @@ void KonquerorApplication::setupAboutData()
     m_aboutData.addAuthor(i18n("Stephan Binner"), i18n("Developer (misc stuff)"), "binner@kde.org");
     m_aboutData.addAuthor(i18n("Ivor Hewitt"), i18n("Developer (AdBlock filter)"), "ivor@ivor.org");
     m_aboutData.addAuthor(i18n("Eduardo Robles Elvira"), i18n("Developer (framework)"), "edulix@gmail.com");
-
+    m_aboutData.addAuthor(i18n("Matthias Kalle Dalheimer"), QLatin1String(""), QStringLiteral("kalle@kde.org"));
+    m_aboutData.addAuthor(i18n("Daniel Molkentin"), QLatin1String(""), QStringLiteral("molkentin@kde.org"));
+    m_aboutData.addCredit(i18n("Leo Savernik"), i18n("JavaScript access controls\n"
+                     "Per-domain policies extensions"),
+                     QStringLiteral("l.savernik@aon.at"));
     KAboutData::setApplicationData(m_aboutData);
 }
 
@@ -222,6 +238,9 @@ int KonquerorApplication::startFirstInstance()
 {
     fixOldStartUrl();
 
+    m_browser = new KonqBrowser(this);
+    connect(this, &KonquerorApplication::configurationChanged, m_browser, &KonqBrowser::configurationChanged);
+
     if (isSessionRestored()) {
         restoreSession();
     } else {
@@ -310,7 +329,7 @@ int KonquerorApplication::performStart(const QString& workingDirectory, bool fir
         QString sessionName = m_parser.value("open-session");
         int result = openSession(sessionName);
         if (result != 0) {
-            KMessageBox::sorry(nullptr, i18nc("The session asked by the user doesn't exist or can't be opened",
+            KMessageBox::error(nullptr, i18nc("The session asked by the user doesn't exist or can't be opened",
                                               "Session %1 couldn't be opened", sessionName));
         }
         //If there was an error opening the session and this is the first instance, don't return immediately
