@@ -22,6 +22,7 @@ namespace KActivities {
 
 class KonqMainWindow;
 class QDBusMessage;
+class KonqBrowser;
 
 namespace KParts {
     class Part;
@@ -42,6 +43,7 @@ public slots:
     void slotReparseConfiguration();
 signals:
     void configurationChanged();
+    void aboutToConfigure();
 
 private slots:
     void slotAddToCombo(const QString &url, const QDBusMessage &msg);
@@ -88,6 +90,8 @@ private:
     KActivities::Consumer* m_activityConsumer;
 #endif
 
+    KonqBrowser *m_browser;
+
 };
 
 #endif
