@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 Carsten Pfeiffer <pfeiffer@kde.org>
-   Copyright (C) 2007 Fredrik Höglund <fredrik@kde.org>
+    SPDX-FileCopyrightText: 2001 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2007 Fredrik Höglund <fredrik@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Own
@@ -154,7 +141,7 @@ KonqCombo::KonqCombo(QWidget *parent)
     // Connect to the returnPressed signal when completionMode == CompletionNone. #314736
     slotCompletionModeChanged(completionMode());
 
-    connect(KonqHistoryManager::kself(), &KParts::HistoryProvider::cleared, this, &KonqCombo::slotCleared);
+    connect(KonqHistoryManager::kself(), &HistoryProvider::cleared, this, &KonqCombo::slotCleared);
     connect(this, &KHistoryComboBox::cleared, this, &KonqCombo::slotCleared);
     // The overload resolution is still needed until QComboBox::highlight(QString)
     // is either removed or hidden.
