@@ -348,6 +348,7 @@ Q_SIGNALS:
     void viewAdded(KonqView *view);
     void viewRemoved(KonqView *view);
     void popupItemsDisturbed();
+    void aboutToConfigure();
 
 public Q_SLOTS:
     void updateViewModeActions();
@@ -361,14 +362,11 @@ public Q_SLOTS:
     void slotPopupMenu(const QPoint &global, const KFileItemList &items, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &browserArgs, KParts::BrowserExtension::PopupFlags flags, const KParts::BrowserExtension::ActionGroupMap &);
     void slotPopupMenu(const QPoint &global, const QUrl &url, mode_t mode, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &browserArgs, KParts::BrowserExtension::PopupFlags f, const KParts::BrowserExtension::ActionGroupMap &);
 
-    /**
-     * __NEEEEVER__ call this method directly. It relies on sender() (the part)
-     */
-    void slotOpenURLRequest(const QUrl &url, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &browserArgs);
+    void slotOpenURLRequest(const QUrl &url, KonqOpenURLRequest &req);
 
-    void openUrlRequestHelper(KonqView *childView, const QUrl &url, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &browserArgs);
+    void openUrl(KonqView *childView, const QUrl &url, KonqOpenURLRequest &req);
 
-    void slotCreateNewWindow(const QUrl &url, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &browserArgs,
+    void slotCreateNewWindow(const QUrl &url, KonqOpenURLRequest& req,
                              const KParts::WindowArgs &windowArgs = KParts::WindowArgs(),
                              KParts::ReadOnlyPart **part = nullptr);
 
@@ -782,7 +780,7 @@ private: // members
     //The last time the window was deactivated, stored as millisecond from epoch
     qint64 m_lastDeactivationTime = 0;
     
-    friend class KonqBrowserInterface;
+    friend class KonqBrowserWindowInterface;
 };
 
 #endif // KONQMAINWINDOW_H
