@@ -16,7 +16,8 @@
 #include "konqtabs.h"
 #include "konqhistorymanager.h"
 #include "konqpixmapprovider.h"
-#include "konqbrowserinterface.h"
+#include "implementations/konqbrowserwindowinterface.h"
+#include "interfaces/downloaderextension.h"
 
 #include <kio/job.h>
 #include <kio/jobuidelegate.h>
@@ -235,6 +236,24 @@ void KonqView::openUrl(const QUrl &url, const QString &locationBarURL,
 #endif
 }
 
+void KonqView::switchEmbeddingPart(const QString& newPluginId, const QString& newInternalViewMode)
+{
+    if (service().pluginId() == newPluginId) {
+        return;
+    }
+    //We don't want to delete the temporary file, otherwise the new part won't have a file to display
+    stop(true);
+    lockHistory();
+    const QUrl origUrl = url();
+    const QString locationBarURL = m_sLocationBarURL;
+    bool tempFile = !m_tempFile.isEmpty();
+    changePart(serviceType(), newPluginId);
+    openUrl(origUrl, locationBarURL, {}, tempFile);
+    if (!newInternalViewMode.isEmpty() && newInternalViewMode != internalViewMode()){
+        setInternalViewMode(newInternalViewMode);
+    }
+}
+
 void KonqView::switchView(KonqViewFactory &viewFactory)
 {
     //qCDebug(KONQUEROR_LOG);
@@ -370,15 +389,29 @@ void KonqView::connectPart()
                 m_pMainWindow, SLOT(slotInternalViewModeChanged()));
     }
 
+    if (m_pPart) {
+        KonqInterfaces::DownloaderExtension *dext = KonqInterfaces::DownloaderExtension::downloader(m_pPart);
+        if (dext) {
+            connect(dext, &KonqInterfaces::DownloaderExtension::downloadAndOpenUrl, m_pMainWindow, [dext, this](const QUrl &url, int id, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &bargs, bool temp){
+                    KonqOpenURLRequest req(args, bargs, dext->part(), true, id);
+                    req.tempFile = temp;
+                    m_pMainWindow->slotOpenURLRequest(url, req);
+                });
+        }
+    }
+
     KParts::BrowserExtension *ext = browserExtension();
 
     if (ext) {
         
-        KonqBrowserInterface *bi = new KonqBrowserInterface(mainWindow(), m_pPart);
+        KonqBrowserWindowInterface *bi = new KonqBrowserWindowInterface(mainWindow(), m_pPart);
         ext->setBrowserInterface(bi);
         
-        connect(ext, SIGNAL(openUrlRequestDelayed(QUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)),
-                m_pMainWindow, SLOT(slotOpenURLRequest(QUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)));
+        connect(ext, &KParts::BrowserExtension::openUrlRequestDelayed, ext,
+                [ext, this](const QUrl &url, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &bargs){
+                    KonqOpenURLRequest req(args, bargs, qobject_cast<KParts::ReadOnlyPart*>(ext->parent()));
+                    m_pMainWindow->slotOpenURLRequest(url, req);
+                });
 
         if (m_bPopupMenuEnabled) {
             m_bPopupMenuEnabled = false; // force
@@ -394,8 +427,11 @@ void KonqView::connectPart()
         connect(ext, SIGNAL(setPageSecurity(int)),
                 this, SLOT(setPageSecurity(int)));
 
-        connect(ext, SIGNAL(createNewWindow(QUrl,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::WindowArgs,KParts::ReadOnlyPart**)),
-                m_pMainWindow, SLOT(slotCreateNewWindow(QUrl,KParts::OpenUrlArguments,KParts::BrowserArguments,KParts::WindowArgs,KParts::ReadOnlyPart**)));
+        connect(ext, &KParts::BrowserExtension::createNewWindow, ext,
+                [ext, this] (const QUrl &url, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &bargs, const KParts::WindowArgs &wargs ,KParts::ReadOnlyPart** part) {
+                    KonqOpenURLRequest req(args, bargs, qobject_cast<KParts::ReadOnlyPart*>(ext->parent()));
+                    m_pMainWindow->slotCreateNewWindow(url, req, wargs, part);
+                });
 
         connect(ext, SIGNAL(loadingProgress(int)),
                 m_pKonqFrame->statusbar(), SLOT(slotLoadingProgress(int)));
@@ -903,11 +939,15 @@ void KonqView::setUrlLoader(UrlLoader *run)
     m_loader = run;
 }
 
-void KonqView::stop()
+void KonqView::stop(bool keepTemporaryFile)
 {
     //qCDebug(KONQUEROR_LOG);
     m_bAborted = false;
-    finishedWithCurrentURL();
+
+    //Don't remove the temporary file if we're just changing the part used to display it
+    if (!keepTemporaryFile) {
+        finishedWithCurrentURL();
+    }
     if (m_bLoading || m_bPendingRedirection) {
         // aborted -> confirm the pending url. We might as well remove it, but
         // we decided to keep it :)
