@@ -11,16 +11,22 @@
 #include "konqmainwindow.h"
 #include "konqview.h"
 #include "konqurl.h"
+#include "konqdebug.h"
+
+#include "interfaces/downloaderextension.h"
 
 #include <KIO/OpenUrlJob>
 #include <KIO/JobUiDelegate>
+#include <KIO/FileCopyJob>
+#include <KIO/MimeTypeFinderJob>
+#include <KIO/JobUiDelegateFactory>
+#include <KIO/CopyJob>
 #include <KMessageBox>
 #include <KParts/ReadOnlyPart>
 #include <KParts/BrowserInterface>
 #include <KParts/BrowserExtension>
+#include <KParts/BrowserRun>
 #include <KParts/PartLoader>
-#include <KIO/FileCopyJob>
-#include <KIO/MimeTypeFinderJob>
 #include <KJobWidgets>
 #include <KProtocolManager>
 #include <KDesktopFile>
@@ -28,6 +34,7 @@
 #include <KParts/PartLoader>
 #include <KLocalizedString>
 #include <KIO/JobUiDelegateFactory>
+#include <KJobTrackerInterface>
 
 #include <QDebug>
 #include <QArgument>
@@ -36,6 +43,9 @@
 #include <QWebEngineProfile>
 #include <QFileDialog>
 #include <QFileInfo>
+#include <QLoggingCategory>
+
+using namespace KonqInterfaces;
 
 bool UrlLoader::embedWithoutAskingToSave(const QString &mimeType)
 {
@@ -43,8 +53,12 @@ bool UrlLoader::embedWithoutAskingToSave(const QString &mimeType)
     if (s_mimeTypes.isEmpty()) {
         QStringList names{QStringLiteral("kfmclient_html"), QStringLiteral("kfmclient_dir"), QStringLiteral("kfmclient_war")};
         for (const QString &name : names) {
-            KPluginMetaData md = findPartById(name);
-            s_mimeTypes.append(md.mimeTypes());
+            KService::Ptr s = KService::serviceByStorageId(name);
+            if (s) {
+                s_mimeTypes.append(s->mimeTypes());
+            } else {
+                qCDebug(KONQUEROR_LOG()) << "Couldn't find service" << name;
+            }
         }
         //The user may want to save xml files rather than embedding them
         //TODO: is there a better way to do this?
@@ -59,12 +73,20 @@ bool UrlLoader::isExecutable(const QString& mimeType)
 }
 
 UrlLoader::UrlLoader(KonqMainWindow *mainWindow, KonqView *view, const QUrl &url, const QString &mimeType, const KonqOpenURLRequest &req, bool trustedSource, bool dontEmbed):
-    QObject(mainWindow), m_mainWindow(mainWindow), m_url(url), m_mimeType(mimeType), m_request(req), m_view(view), m_trustedSource(trustedSource), m_dontEmbed(dontEmbed),
-    m_jobErrorCode(0), m_protocolAllowsReading(KProtocolManager::supportsReading(m_url))
+    QObject(mainWindow),
+    m_mainWindow(mainWindow),
+    m_url(url),
+    m_mimeType(mimeType),
+    m_request(req),
+    m_view(view),
+    m_trustedSource(trustedSource),
+    m_dontEmbed(dontEmbed),
+    m_protocolAllowsReading(KProtocolManager::supportsReading(m_url) || !KProtocolInfo::isKnownProtocol(m_url)), // If the protocol is unknown, assume it allows reading
+    m_letRequestingPartDownloadUrl(req.letPartPerformDownload),
+    m_forceSave(m_request.args.metaData().contains(QStringLiteral("ForceSave")))
 {
-    if (!isMimeTypeKnown(m_mimeType)) {
-        m_mimeType = m_request.args.mimeType();
-    }
+    getDownloaderJobFromPart();
+    determineStartingMimetype();
     m_dontPassToWebEnginePart = m_request.args.metaData().contains("DontSendToDefaultHTMLPart");
 }
 
@@ -72,6 +94,25 @@ UrlLoader::~UrlLoader()
 {
 }
 
+void UrlLoader::determineStartingMimetype()
+{
+    QMimeDatabase db;
+    if (!m_mimeType.isEmpty()) {
+        if (m_letRequestingPartDownloadUrl || !db.mimeTypeForName(m_mimeType).isDefault()) {
+            return;
+        }
+    }
+
+    m_mimeType = m_request.args.mimeType();
+    //In theory, this should never happen, as parts requesting to download the URL
+    //by themselves should already have set the mimetype. However, let's check, just in case
+    if (m_letRequestingPartDownloadUrl && m_mimeType.isEmpty()) {
+        m_mimeType = QStringLiteral("application/octet-stream");
+    } else if (db.mimeTypeForName(m_mimeType).isDefault()) {
+        m_mimeType.clear();
+    }
+}
+
 QString UrlLoader::mimeType() const
 {
     return m_mimeType;
@@ -79,7 +120,7 @@ QString UrlLoader::mimeType() const
 
 bool UrlLoader::isMimeTypeKnown(const QString &mimeType)
 {
-    return !mimeType.isEmpty() && mimeType != QLatin1String("application/octet-stream");
+    return !mimeType.isEmpty();
 }
 
 void UrlLoader::setView(KonqView* view)
@@ -115,7 +156,7 @@ void UrlLoader::start()
         }
     }
 
-    m_isAsync = m_protocolAllowsReading && !isMimeTypeKnown(m_mimeType);
+    m_isAsync = m_protocolAllowsReading && (!isMimeTypeKnown(m_mimeType) || m_letRequestingPartDownloadUrl);
 }
 
 bool UrlLoader::isViewLocked() const
@@ -129,6 +170,10 @@ void UrlLoader::decideAction()
         m_action = OpenUrlAction::Embed;
         return;
     }
+    if (m_forceSave) {
+        m_action = OpenUrlAction::Save;
+        return;
+    }
     m_action = decideExecute();
     switch (m_action) {
         case OpenUrlAction::Execute:
@@ -138,7 +183,7 @@ void UrlLoader::decideAction()
             m_ready = true;
             return;
         default:
-            if (m_mimeType.isEmpty() && !m_protocolAllowsReading) {
+            if (isMimeTypeKnown(m_mimeType) && !m_protocolAllowsReading) {
                 //If the protocol doesn't allow reading and we don't have a mimetype associated with it,
                 //use the Open action, as we most likely won't be able to find out the mimetype. This is
                 //what happens, for example, for mailto URLs
@@ -168,41 +213,45 @@ void UrlLoader::abort()
 
 void UrlLoader::goOn()
 {
-    if (m_isAsync) {
+    if (m_isAsync && !isMimeTypeKnown(m_mimeType)) {
         launchMimeTypeFinderJob();
     } else {
         decideAction();
-        m_ready = true;
+        m_ready = !m_letRequestingPartDownloadUrl;
         performAction();
     }
 }
 
-bool UrlLoader::decideEmbedOrSave()
+KPluginMetaData UrlLoader::findEmbeddingPart(bool forceServiceName) const
 {
     const QLatin1String webEngineName("webenginepart");
 
     //Use WebEnginePart for konq: URLs even if it's not the default html engine
     if (KonqUrl::hasKonqScheme(m_url)) {
-        m_part = findPartById(webEngineName);
-    } else {
-        //Check whether the view can display the mimetype, but only if the URL hasn't been explicitly
-        //typed by the user: in this case, use the preferred service. This is needed to avoid the situation
-        //where m_view is a Kate part, the user enters the URL of a web page and the page is opened within
-        //the Kate part because it can handle html files.
-        if (m_view && m_request.typedUrl.isEmpty() && m_view->supportsMimeType(m_mimeType)) {
-            m_part = m_view->service();
-        } else {
-            if (!m_request.serviceName.isEmpty()) {
-                // If the service name has been set by the "--part" command line argument
-                // (detected in handleCommandLine() in konqmain.cpp), then use it as is.
-                m_part = findPartById(m_request.serviceName);
-            } else {
-                // Otherwise, use the preferred service for the MIME type.
-                m_part = preferredPart(m_mimeType);
-            }
+        return findPartById(webEngineName);
+    }
+
+    KPluginMetaData part;
+
+    //Check whether the view can display the mimetype, but only if the URL hasn't been explicitly
+    //typed by the user: in this case, use the preferred service. This is needed to avoid the situation
+    //where m_view is a Kate part, the user enters the URL of a web page and the page is opened within
+    //the Kate part because it can handle html files.
+    if (m_view && m_request.typedUrl.isEmpty() && m_view->supportsMimeType(m_mimeType)) {
+        part = m_view->service();
+    } else if (!m_request.serviceName.isEmpty()) {
+        // If the service name has been set by the "--part" command line argument
+        // (detected in handleCommandLine() in konqmain.cpp), then use it as is.
+        part = findPartById(m_request.serviceName);
+        if (!forceServiceName && !part.supportsMimeType(m_mimeType)) {
+            part = KPluginMetaData();
         }
     }
 
+    if (!part.isValid()) {
+        part = preferredPart(m_mimeType);
+    }
+
     /* Corner case: webenginepart can't determine mimetype (gives application/octet-stream) but
      * OpenUrlJob determines a mimetype supported by WebEnginePart (for example application/xml):
      * if the preferred part is webenginepart, we'd get an endless loop because webenginepart will
@@ -220,13 +269,19 @@ bool UrlLoader::decideEmbedOrSave()
         auto findPart = [&webEngineName](const KPluginMetaData &md){return md.pluginId() != webEngineName;};
         QVector<KPluginMetaData>::const_iterator partToUse = std::find_if(parts.constBegin(), parts.constEnd(), findPart);
         if (partToUse != parts.constEnd()) {
-            m_part = *partToUse;
+            part = *partToUse;
         } else {
-            m_part = KPluginMetaData();
+            part = KPluginMetaData();
         }
     }
+    return part;
+}
 
-    //If we can't find a service, return false, so that the caller can use decideOpenOrSave to allow the
+bool UrlLoader::decideEmbedOrSave()
+{
+    m_part = findEmbeddingPart();
+
+    //If we can't find a part, return false, so that the caller can use decideOpenOrSave to allow the
     //user the possibility of opening the file, since embedding wasn't possibile
     if (!m_part.isValid()) {
         return false;
@@ -263,6 +318,18 @@ void UrlLoader::decideOpenOrSave()
     }
 
     m_action = answerWithService.first;
+
+    //If the URL should be opened in an external application and it should be downloaded by the requesting part,
+    //ensure it's not downloaded in Konqueror's temporary directory but in the global temporary directory,
+    //otherwise if the user closes Konqueror before closing the application, there could be issues because the
+    //external application wouldn't find the file anymore.
+    //Problem: if the application doesn't support the --tempfile switch, the file will remain even after both Konqueror
+    //and the external application are closed and will only be removed automatically if the temporary directory is deleted
+    //or emptied.
+    if (m_letRequestingPartDownloadUrl && m_action == OpenUrlAction::Open && m_partDownloaderJob) {
+        QString fileName = QFileInfo(m_partDownloaderJob->downloadPath()).fileName();
+        m_partDownloaderJob->setDownloadPath(QDir::temp().filePath(fileName));
+    }
     m_service = answerWithService.second;
 }
 
@@ -306,6 +373,17 @@ UrlLoader::OpenUrlAction UrlLoader::decideExecute() const {
 
 void UrlLoader::performAction()
 {
+    //If we still aren't ready, it means that the part wants to download the URL
+    //by itself. Do this only when opening or embedding, however, since when
+    //saving we first need to ask the user where to save. save() will launch the
+    //job itself.
+    //When the part has finished downloading the URL, the slot connected with the
+    //job's result() signal will call again this function, after setting m_ready
+    //to true
+    if (!m_ready && (m_action == OpenUrlAction::Embed || m_action == OpenUrlAction::Open)) {
+        downloadForEmbeddingOrOpening();
+        return;
+    }
     switch (m_action) {
         case OpenUrlAction::Embed:
             embed();
@@ -326,6 +404,87 @@ void UrlLoader::performAction()
     }
 }
 
+void UrlLoader::getDownloaderJobFromPart()
+{
+    if (!m_letRequestingPartDownloadUrl) {
+        return;
+    }
+    DownloaderExtension *iface = downloaderInterface();
+    if (iface) {
+        m_partDownloaderJob = iface->downloadJob(m_url, m_request.downloadId, this);
+    } else {
+        qCDebug(KONQUEROR_LOG) << "Wanting to let part download" << m_url << "but part doesn't implement the DownloaderInterface";
+    }
+
+    //If we can't get a job for whatever reason (it shouldn't happen, but let's be sure)
+    //try to open the URL in the usual way. Maybe it'll work (most likely, it will if
+    //there's no need to have special cookies set to access it)
+    if (!m_partDownloaderJob) {
+        qCDebug(KONQUEROR_LOG) << "Couldn't get DownloadJob for" << m_url << "from part" << m_part;
+        m_letRequestingPartDownloadUrl = false;
+        m_request.tempFile = false; //Opening a remote URL with tempFile will fail
+    }
+}
+
+void UrlLoader::downloadForEmbeddingOrOpening()
+{
+    //This shouldn't happen
+    if (!m_partDownloaderJob) {
+        done();
+        return;
+    }
+    m_partDownloaderJob->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_mainWindow));
+    KJobTrackerInterface *t = KIO::getJobTracker();
+    if (t) {
+        t->registerJob(m_partDownloaderJob);
+    }
+    connect(m_partDownloaderJob, &KJob::result, this, &UrlLoader::downloadForEmbeddingOrOpeningDone);
+    connect(m_partDownloaderJob, &KJob::result, this, &UrlLoader::jobFinished);
+    m_partDownloaderJob->start();
+}
+
+void UrlLoader::downloadForEmbeddingOrOpeningDone(KJob* job)
+{
+    DownloaderJob *dj = qobject_cast<DownloaderJob*>(job);
+    if (dj && dj->error() == 0) {
+        QUrl origUrl(m_url);
+        m_url = QUrl::fromLocalFile(dj->downloadPath());
+        m_ready = true;
+        m_request.tempFile = true;
+    } else if (!dj || dj->error() == KIO::ERR_USER_CANCELED) {
+        m_action = OpenUrlAction::DoNothing;
+        m_ready = true;
+    }
+    checkDownloadedMimetype();
+    performAction();
+}
+
+void UrlLoader::checkDownloadedMimetype()
+{
+    QMimeDatabase db;
+    QMimeType typeByContent = db.mimeTypeForFile(m_url.path(), QMimeDatabase::MatchContent);
+    QMimeType typeByName = db.mimeTypeForFile(m_url.path(), QMimeDatabase::MatchExtension);
+    QString type = (typeByName.inherits(typeByContent.name()) ? typeByName : typeByContent).name();
+    if (type == m_mimeType) {
+        return;
+    }
+    m_mimeType = type;
+    //The URL is a local file now, so there are no problems in opening it with WebEnginePart
+    m_dontPassToWebEnginePart = false;
+    if (shouldEmbedThis()) {
+        m_part = findEmbeddingPart(false);
+        if (m_part.isValid()) {
+            m_action = OpenUrlAction::Embed;
+            return;
+        }
+    }
+    m_action = OpenUrlAction::Open;
+    if (m_service && m_service->hasMimeType(m_mimeType)) {
+        return;
+    }
+    m_service = KApplicationTrader::preferredService(m_mimeType);
+}
+
 void UrlLoader::done(KJob *job)
 {
     //Ensure that m_mimeType and m_request.args.mimeType are equal, since it's not clear what will be used
@@ -334,10 +493,14 @@ void UrlLoader::done(KJob *job)
         jobFinished(job);
     }
     emit finished(this);
+    //If we reach here and m_partDownloaderJob->finished() is false, it means the job hasn' been started in the first place,
+    //(because the user canceled the download), so kill it
+    if (m_partDownloaderJob && !m_partDownloaderJob->finished()) {
+        m_partDownloaderJob->kill();
+    }
     deleteLater();
 }
 
-
 bool UrlLoader::serviceIsKonqueror(KService::Ptr service)
 {
     return service && (service->desktopEntryName() == QLatin1String("konqueror") || service->exec().trimmed() == QLatin1String("konqueror") || service->exec().trimmed().startsWith(QLatin1String("kfmclient")));
@@ -346,7 +509,7 @@ bool UrlLoader::serviceIsKonqueror(KService::Ptr service)
 void UrlLoader::launchMimeTypeFinderJob()
 {
     m_mimeTypeFinderJob = new KIO::MimeTypeFinderJob(m_url, this);
-    m_mimeTypeFinderJob->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_mainWindow));
+    m_mimeTypeFinderJob->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_mainWindow));
     m_mimeTypeFinderJob->setSuggestedFileName(m_request.suggestedFileName);
     connect(m_mimeTypeFinderJob, &KIO::MimeTypeFinderJob::result, this, [this](KJob*){mimetypeDeterminedByJob();});
     m_mimeTypeFinderJob->start();
@@ -354,34 +517,44 @@ void UrlLoader::launchMimeTypeFinderJob()
 
 void UrlLoader::mimetypeDeterminedByJob()
 {
-    if (!m_mimeTypeFinderJob->error()) {
-        m_mimeType=m_mimeTypeFinderJob->mimeType();
-        //Only check whether the URL represents an archive when it is a local file. This can be either because
-        //QUrl::isLocalFile returns true or because its scheme corresponds to a protocol with class :local
-        //(for example, tar)
-        if (m_url.isLocalFile() || KProtocolInfo::protocolClass(m_url.scheme()) == QLatin1String(":local")) {
-            detectArchiveSettings();
-        }
-        decideAction();
-    } else {
+    if (m_mimeTypeFinderJob->error()) {
         m_jobErrorCode = m_mimeTypeFinderJob->error();
         m_url = KParts::BrowserRun::makeErrorUrl(m_jobErrorCode, m_mimeTypeFinderJob->errorString(), m_url);
         m_mimeType = QStringLiteral("text/html");
         m_action = OpenUrlAction::Embed;
+        performAction();
+        return;
     }
-    performAction();
+    m_mimeType=m_mimeTypeFinderJob->mimeType();
+    if (m_mimeType.isEmpty()) {
+        //Ensure the mimetype is not empty so that goOn (called below) won't attempt to determine it again
+        //In theory, KIO::MimeTypeFinderJob::mimeType() should never return an empty string
+        m_mimeType = QStringLiteral("application/octet-stream");
+    }
+    //Only check whether the URL represents an archive when it is a local file. This can be either because
+    //QUrl::isLocalFile returns true or because its scheme corresponds to a protocol with class :local
+    //(for example, tar)
+    if (m_url.isLocalFile() || KProtocolInfo::protocolClass(m_url.scheme()) == QLatin1String(":local")) {
+        detectArchiveSettings();
+    }
+    goOn();
 }
 
 bool UrlLoader::shouldUseDefaultHttpMimeype() const
 {
-    const QVector<QString> webengineSchemes = {"error", "konq"};
     if (m_dontPassToWebEnginePart || isMimeTypeKnown(m_mimeType)) {
         return false;
-    } else if (m_url.scheme().startsWith(QStringLiteral("http")) || webengineSchemes.contains(m_url.scheme())) {
-        return true;
-    } else {
-        return false;
     }
+    const QVector<QString> webengineSchemes = {QStringLiteral("error"), QStringLiteral("konq")};
+    return m_url.scheme().startsWith(QStringLiteral("http")) || webengineSchemes.contains(m_url.scheme());
+}
+
+DownloaderExtension* UrlLoader::downloaderInterface() const
+{
+    if (!m_request.requestingPart) {
+        return nullptr;
+    }
+    return DownloaderExtension::downloader(m_request.requestingPart);
 }
 
 void UrlLoader::detectSettingsForRemoteFiles()
@@ -389,7 +562,17 @@ void UrlLoader::detectSettingsForRemoteFiles()
     if (m_url.isLocalFile()) {
         return;
     }
-    if (shouldUseDefaultHttpMimeype()) {
+
+    if (m_url.scheme() == QLatin1String("error")) {
+        m_letRequestingPartDownloadUrl = false; //error URLs can never be downloaded
+        m_mimeType = QLatin1String("text/html");
+        m_request.args.setMimeType(QStringLiteral("text/html"));
+    }
+    else if (shouldUseDefaultHttpMimeype()) {
+        // If a part which supports html asked to download the URL, it means it's not html, so don't change its mimetype
+        if (m_letRequestingPartDownloadUrl && m_part.supportsMimeType(QStringLiteral("text/html"))) {
+            return;
+        }
         m_mimeType = QLatin1String("text/html");
         m_request.args.setMimeType(QStringLiteral("text/html"));
     } else if (!m_trustedSource && isTextExecutable(m_mimeType)) {
@@ -453,6 +636,8 @@ void UrlLoader::detectSettingsForLocalFiles()
         return;
     }
 
+    m_letRequestingPartDownloadUrl = false; //If the file is local, there's no need to download it
+
     m_jobErrorCode = checkAccessToLocalFile(m_url.path());
 
     if (!m_mimeType.isEmpty()) {
@@ -476,7 +661,6 @@ void UrlLoader::detectSettingsForLocalFiles()
     }
 }
 
-
 bool UrlLoader::shouldEmbedThis() const
 {
     return !m_dontEmbed && (m_request.forceAutoEmbed || KonqFMSettings::settings()->shouldEmbed(m_mimeType));
@@ -501,29 +685,44 @@ void UrlLoader::embed()
 
 void UrlLoader::save()
 {
-    QFileDialog *dlg = new QFileDialog(m_mainWindow);
-    dlg->setAcceptMode(QFileDialog::AcceptSave);
-    dlg->setWindowTitle(i18n("Save As"));
-    dlg->setOption(QFileDialog::DontConfirmOverwrite, false);
-    dlg->setAttribute(Qt::WA_DeleteOnClose);
+    QFileDialog dlg(m_mainWindow);
+    dlg.setAcceptMode(QFileDialog::AcceptSave);
+    dlg.setWindowTitle(i18n("Save As"));
+    dlg.setOption(QFileDialog::DontConfirmOverwrite, false);
     QString suggestedName = !m_request.suggestedFileName.isEmpty() ? m_request.suggestedFileName : m_url.fileName();
-    dlg->selectFile(suggestedName);
-    dlg->setDirectory(QStandardPaths::writableLocation(QStandardPaths::DownloadLocation));
-    auto savePrc = [this, dlg](){
-        QUrl dest = dlg->selectedUrls().value(0);
-        if (dest.isValid()) {
-            saveUrlUsingKIO(m_url, dest);
-        }
-    };
-    connect(dlg, &QDialog::accepted, dlg, savePrc);
-    dlg->show();
+    dlg.selectFile(suggestedName);
+    dlg.setDirectory(QStandardPaths::writableLocation(QStandardPaths::DownloadLocation));
+    //NOTE: we can't use QDialog::open() because the dialog needs to be synchronous so that we can call
+    //DownloaderJob::setDownloadPath()
+    if (dlg.exec() == QDialog::Rejected) {
+        done();
+        return;
+    }
+    performSave(m_url, dlg.selectedUrls().value(0));
 }
 
-void UrlLoader::saveUrlUsingKIO(const QUrl& orig, const QUrl& dest)
+void UrlLoader::performSave(const QUrl& orig, const QUrl& dest)
 {
-    KIO::FileCopyJob *job = KIO::file_copy(orig, dest, -1, KIO::Overwrite);
+    KJob *job = nullptr;
+    if (m_letRequestingPartDownloadUrl) {
+        getDownloaderJobFromPart();
+        if (m_partDownloaderJob) {
+            m_partDownloaderJob->setDownloadPath(dest.path());
+        }
+        job = m_partDownloaderJob;
+    } else {
+        KIO::file_copy(orig, dest, -1, KIO::Overwrite);
+    }
+    if (!job) {
+        done();
+        return;
+    }
     KJobWidgets::setWindow(job, m_mainWindow);
-    job->uiDelegate()->setAutoErrorHandlingEnabled(true);
+    KJobTrackerInterface *t = KIO::getJobTracker();
+    if (t) {
+        t->registerJob(job);
+    }
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_mainWindow));
     connect(job, &KJob::finished, this, [this, job](){done(job);});
     job->start();
 }
@@ -535,6 +734,10 @@ void UrlLoader::open()
     if (m_service && serviceIsKonqueror(m_service) && m_mainWindow->refuseExecutingKonqueror(m_mimeType)) {
         return;
     }
+    if (m_jobErrorCode != 0) {
+        done();
+        return;
+    }
 
     KJob *job = nullptr;
     KIO::ApplicationLauncherJob *j = new KIO::ApplicationLauncherJob(m_service);
@@ -568,19 +771,19 @@ bool UrlLoader::isTextExecutable(const QString &mimeType)
 
 UrlLoader::OpenSaveAnswer UrlLoader::askSaveOrOpen(OpenEmbedMode mode) const
 {
-    KParts::BrowserOpenOrSaveQuestion dlg(m_mainWindow, m_url, m_mimeType);
+    BrowserOpenOrSaveQuestion dlg(m_mainWindow, m_url, m_mimeType);
     dlg.setSuggestedFileName(m_request.suggestedFileName);
-    dlg.setFeatures(KParts::BrowserOpenOrSaveQuestion::ServiceSelection);
-    KParts::BrowserOpenOrSaveQuestion::Result ans = mode == OpenEmbedMode::Open ? dlg.askOpenOrSave() : dlg.askEmbedOrSave();
+    dlg.setFeatures(BrowserOpenOrSaveQuestion::ServiceSelection);
+    BrowserOpenOrSaveQuestion::Result ans = mode == OpenEmbedMode::Open ? dlg.askOpenOrSave() : dlg.askEmbedOrSave();
     OpenUrlAction action;
     switch (ans) {
-        case KParts::BrowserOpenOrSaveQuestion::Save:
+        case BrowserOpenOrSaveQuestion::Save:
             action = OpenUrlAction::Save;
             break;
-        case KParts::BrowserOpenOrSaveQuestion::Open:
+        case BrowserOpenOrSaveQuestion::Open:
             action = OpenUrlAction::Open;
             break;
-        case KParts::BrowserOpenOrSaveQuestion::Embed:
+        case BrowserOpenOrSaveQuestion::Embed:
             action = OpenUrlAction::Embed;
             break;
         default:
@@ -643,3 +846,4 @@ QDebug operator<<(QDebug dbg, UrlLoader::OpenUrlAction action)
     }
     return dbg;
 }
+
