@@ -10,12 +10,13 @@
 #define URLLLOADER_H
 
 #include "konqopenurlrequest.h"
+#include "browseropenorsavequestion.h"
 
 #include <QObject>
 #include <QUrl>
 
 #include <KService>
-#include <KParts/BrowserOpenOrSaveQuestion>
+#include <KJob>
 
 namespace KParts {
     class ReadOnlyPart;
@@ -27,10 +28,14 @@ namespace KIO {
     class ApplicationLauncherJob;
     class MimeTypeFinderJob;
 }
-
+namespace KonqInterfaces {
+    class DownloaderExtension;
+    class DownloaderJob;
+}
 class KonqMainWindow;
 class KonqView;
 
+
 /**
  * @brief Class which takes care of finding out what to do with an URL and carries out the chosen action
  *
@@ -45,7 +50,17 @@ class KonqView;
  * - call viewToUse() to find out where the URL should be opened. If needed, create a new view and call setView()
  * passing the new view
  * - call goOn(): this will asynchronously determine the mimetype and the action to carry out, if not already done,
- * and perform the action itself
+ * and perform the action itself.
+ *
+ * @internal
+ * For remote files, what happens after goOn depends on whether the metadata associated with the request to open the
+ * URL (`m_request.args.metaData()`) contains the key DownloaderInterface::requestDownloadByPartKey():
+ * - if the key doesn't exist, this class will determine the mimetype of the URL (if needed), then embed, open or save it
+ *   depending on the mimetype and the user's previous choices
+ * - if the key exists, (after determining the mimetype of the URL, if not already known), this class will check whether
+ *   the requesting part implements the DownloaderInterface. If so, it'll let the job returned by DownloaderInterface::downloadJob()
+ *   to download the URL, then it will update #m_url so that it contains the path of the downloaded file. It then proceeds as
+ *   in the above case. If the file should be saved, it'll simply moved from the download location to the location chosen by the user
  */
 class UrlLoader : public QObject
 {
@@ -63,7 +78,7 @@ public:
      * @param trustedSource whether the source of the URL is trusted
      * @param forceOpen tells never to embed the URL
      */
-    UrlLoader(KonqMainWindow *mainWindow, KonqView *view, const QUrl &url, const QString &mimeType, const KonqOpenURLRequest &req, bool trustedSource, bool forceOpen=false);
+    UrlLoader(KonqMainWindow* mainWindow, KonqView* view, const QUrl& url, const QString& mimeType, const KonqOpenURLRequest& req, bool trustedSource, bool dontEmbed = false);
     ~UrlLoader();
 
 
@@ -153,6 +168,13 @@ private slots:
     void jobFinished(KJob* job);
     void done(KJob *job=nullptr);
 
+    /**
+     * @brief Slot called when a part which has asked to download itself the URL has finished doing so
+     *
+     * @param job the DownloaderJob used by the part to download the URL
+     */
+    void downloadForEmbeddingOrOpeningDone(KJob *job);
+
 private:
 
     void embed();
@@ -161,7 +183,7 @@ private:
     void save();
 
     bool shouldEmbedThis() const;
-    void saveUrlUsingKIO(const QUrl &orig, const QUrl &dest);
+    void performSave(const QUrl &orig, const QUrl &dest);
     void detectArchiveSettings();
     void detectSettingsForLocalFiles();
     void detectSettingsForRemoteFiles();
@@ -178,6 +200,79 @@ private:
     void decideAction();
     bool isViewLocked() const;
 
+    /**
+     * @brief Checks whether a file downloaded by a part really has the mime type described by the HTML header
+     *
+     * This function is called when the part requesting to download an URL wants to perform the download itself,
+     * after the download has finished. It attempts to determine the mime type both using the file contents and the
+     * file extension. The algorithm used is the following:
+     * - determine the mime type using the contents
+     * - determine the mime type using the extension
+     * - if the mime type determined from the extension inherits the one determined by content, use the former, otherwise
+     *  use the latter.
+     * This way to determine the mimetype is different from that used by `QMimeDataBase::mimeTypeForFile` when called
+     * with `QMimeDatabase::MatchDefault`, which only checks the content as a fallback.
+     *
+     * If the mime type is different from the original one, it replaces the original one and attempts to determine
+     * again what to do with the file. If the determined mime type is `application/octet-stream`, the original mime type
+     * is kept.
+     *
+     * This function is only called if the user had decided to embed or open the file; it isn't called if the user
+     * decided to save it (saving doesn't depend on the mime type).
+     *
+     * @note This function is needed because sometimes the mime type in the HTTP header is different from the actual
+     * mimetype of the file.
+     */
+    void checkDownloadedMimetype();
+
+    /**
+     * @brief Finds the part to use to embed the URL
+     *
+     * The part is found according to the mimetype and the user preferences. If #m_dontPassToWebEnginePart is `true`
+     * `webenginepart` won't be returned (even if no other parts are available).
+     *
+     * If the `serviceName` variable of #m_request is not empty, that part will be used, regardless of other user
+     * preferences. If @p forceServiceName is `false`, that part will only be used if it actually supports the mimetype
+     * @param forceServiceName whether to force the use of the part whose name is in `m_request.serviceName`, even if
+     * it doesn't support the mimetype
+     * @return the metadata representing the chosen part or an empty `KPluginMetaData` if no suitable part can be found
+     * @see m_dontPassToWebEnginePart
+     */
+    KPluginMetaData findEmbeddingPart(bool forceServiceName=true) const;
+
+    /**
+     * @brief Determines #m_mimeType in the constructor
+     *
+     * The algorithm used is the following:
+     * - if #m_mimeType isn't empty or a default mimetype, use it
+     * - if #m_request.args.mimeType() isn't empty or a default mimetype, use it
+     * - otherwise use an empty string
+     */
+    void determineStartingMimetype();
+
+    /**
+     * @brief Casts the requesting part or one of its children to a DownloaderInterface*, if possible
+     * @note Since this uses DownloaderInterface::interface(), it's slower than a simple cast
+     * @return the requesting part or one of its children casted to a DownloaderInterface* or `nullptr` if
+     * the requesting part is `nullptr` or neither it nor its children implement DownloaderInterface
+     */
+    KonqInterfaces::DownloaderExtension* downloaderInterface() const;
+
+    /**
+     * @brief Retrieves from the requesting part a DownloaderJob to download the URL
+     *
+     * The retrieved job is stored in #m_partDownloaderJob. If downloaderInterface()
+     * returns `nullptr`, #m_partDownloaderJob is set to `nullptr`
+     */
+    void getDownloaderJobFromPart();
+
+    /**
+     * @brief Downloads the URL using the job provided by the requesting part, if any
+     *
+     * If #m_partDownloaderJob is `nullptr`, nothing is done
+     */
+    void downloadForEmbeddingOrOpening();
+
     /**
      * @brief Checks whether the given file can be read and, in case of a directory, entered into
      *
@@ -221,6 +316,16 @@ private:
 private:
     QPointer<KonqMainWindow> m_mainWindow;
     QUrl m_url;
+
+    /**
+     * @brief The mimetype of the URL
+     *
+     * If this is empty, it means that the mimetype isn't known and must be determined somehow.
+     * If this is not empty, it is assumed that its value is the correct mimetype for the URL and
+     * no other attempts to determine the mimetype will be done (even if this is the default mimetype).
+     * @see launchMimeTypeFinderJob()
+     * @see mimetypeDeterminedByJob()
+     */
     QString m_mimeType;
     KonqOpenURLRequest m_request;
     KonqView *m_view;
@@ -234,10 +339,13 @@ private:
     QPointer<KIO::OpenUrlJob> m_openUrlJob;
     QPointer<KIO::ApplicationLauncherJob> m_applicationLauncherJob;
     QPointer<KIO::MimeTypeFinderJob> m_mimeTypeFinderJob;
+    QPointer<KonqInterfaces::DownloaderJob> m_partDownloaderJob;
     QString m_oldLocationBarUrl;
-    int m_jobErrorCode;
+    int m_jobErrorCode = 0;
     bool m_dontPassToWebEnginePart;
     bool m_protocolAllowsReading;
+    bool m_letRequestingPartDownloadUrl = false; ///<Whether the URL should be downloaded by the part before opening/embedding/saving it
+    bool m_forceSave; ///<Whether the part explicitly asked for the URL to be saved
 };
 
 QDebug operator<<(QDebug dbg, UrlLoader::OpenUrlAction action);
