@@ -18,11 +18,14 @@
 #include <webenginepart_debug.h>
 #include "webenginepartcontrols.h"
 #include "navigationrecorder.h"
+#include "profile.h"
+#include "webenginepart_ext.h"
 
 #include <QWebEngineCertificateError>
 #include <QWebEngineSettings>
 #include <QWebEngineProfile>
 #include <KDialogJobUiDelegate>
+#include <QWebEngineView>
 
 #include <KMessageBox>
 #include <KLocalizedString>
@@ -35,7 +38,7 @@
 #include <KIO/Job>
 #include <KIO/AccessManager>
 #include <KIO/CommandLauncherJob>
-#include <KParts/HtmlExtension>
+#include <KJobTrackerInterface>
 #include <KUserTimestamp>
 #include <KPasswdServerClient>
 #include <KParts/BrowserInterface>
@@ -46,6 +49,7 @@
 #include <QDesktopWidget>
 #include <QFileDialog>
 #include <QDialogButtonBox>
+#include <QMimeDatabase>
 
 #include <QFile>
 #include <QAuthenticator>
@@ -60,9 +64,12 @@
 #include <KToggleFullScreenAction>
 //#include <QWebSecurityOrigin>
 #include "utils.h"
+#include "htmlextension.h"
+
+using namespace KonqInterfaces;
 
 WebEnginePage::WebEnginePage(WebEnginePart *part, QWidget *parent)
-        : QWebEnginePage(parent),
+        : QWebEnginePage(KonqWebEnginePart::Profile::defaultProfile(), parent),
          m_kioErrorCode(0),
          m_ignoreError(false),
          m_part(part),
@@ -94,6 +101,10 @@ WebEnginePage::WebEnginePage(WebEnginePart *part, QWidget *parent)
     m_dropOperationTimer->setSingleShot(true);
 #endif
 
+#if QT_VERSION_MAJOR == 6
+    connect(this, &QWebEnginePage::certificateError, this, &WebEnginePage::handleCertificateError);
+#endif
+
     //If this part is displaying the developer tools for another part, inform the other page it's not displaying the developer tools anymore.
     //I'm not sure this is needed, but I think it's better to do it, just to be on the safe side
     auto unsetInspectedPageIfNeeded = [this](bool ok) {
@@ -117,63 +128,131 @@ const WebSslInfo& WebEnginePage::sslInfo() const
     return m_sslInfo;
 }
 
+#if QT_VERSION_MAJOR == 6
+QWidget *WebEnginePage::view() const
+{
+    return QWebEngineView::viewForPage(this);
+}
+#endif
+
 void WebEnginePage::setSslInfo (const WebSslInfo& info)
 {
     m_sslInfo = info;
 }
 
-static void checkForDownloadManager(QWidget* widget, QString& cmd)
+static QString checkForDownloadManager(QWidget* widget)
 {
-    cmd.clear();
     KConfigGroup cfg (KSharedConfig::openConfig(QStringLiteral("konquerorrc"), KConfig::NoGlobals), "HTML Settings");
     const QString fileName (cfg.readPathEntry("DownloadManager", QString()));
-    if (fileName.isEmpty())
-        return;
+    if (fileName.isEmpty()) {
+        return QString();
+    }
 
     const QString exeName = QStandardPaths::findExecutable(fileName);
     if (exeName.isEmpty()) {
-        KMessageBox::detailedSorry(widget,
+        KMessageBox::detailedError(widget,
                                    i18n("The download manager (%1) could not be found in your installation.", fileName),
                                    i18n("Try to reinstall it and make sure that it is available in $PATH. \n\nThe integration will be disabled."));
         cfg.writePathEntry("DownloadManager", QString());
         cfg.sync();
+        return QString();
+    }
+    return exeName;
+}
+
+bool WebEnginePage::downloadWithExternalDonwloadManager(const QUrl &url)
+{
+    if (url.isLocalFile()) {
+        return false;
+    }
+
+    KConfigGroup cfg (KSharedConfig::openConfig(QStringLiteral("konquerorrc"), KConfig::NoGlobals), "HTML Settings");
+    const QString fileName (cfg.readPathEntry("DownloadManager", QString()));
+    if (fileName.isEmpty()) {
+        return false;
+    }
+
+    const QString managerExe = QStandardPaths::findExecutable(fileName);
+    if (managerExe.isEmpty()) {
+        KMessageBox::detailedError(view(),
+                                   i18n("The download manager (%1) could not be found in your installation.", fileName),
+                                   i18n("Try to reinstall it and make sure that it is available in $PATH. \n\nThe integration will be disabled."));
+        cfg.writePathEntry("DownloadManager", QString());
+        cfg.sync();
+        return false;
+    }
+
+    //qCDebug(WEBENGINEPART_LOG) << "Calling command" << cmd;
+    KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(managerExe, {url.toString()});
+    job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, view()));
+    job->start();
+    return true;
+}
+
+void WebEnginePage::requestDownload(QWebEngineDownloadItem *item, bool newWindow, bool requestSave)
+{
+    QUrl url = item->url();
+    if (downloadWithExternalDonwloadManager(url)) {
+        item->cancel();
+        item->deleteLater();
         return;
     }
 
-    cmd = exeName;
-}
-
-void WebEnginePage::downloadItem(QWebEngineDownloadItem *it, bool newWindow)
-{
-    QUrl url = it->url();
-    // Integration with a download manager...
-    if (!url.isLocalFile()) {
-        QString managerExe;
-        checkForDownloadManager(view(), managerExe);
-        if (!managerExe.isEmpty()) {
-            //qCDebug(WEBENGINEPART_LOG) << "Calling command" << cmd;
-            KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(managerExe, {url.toString()});
-            job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, view()));
-            job->start();
-            return;
-        }
+    WebEngineDownloaderExtension *downloader = m_part->downloader();
+    if (downloader) {
+        downloader->addDownloadRequest(item);
     }
-    KParts::BrowserArguments bArgs;
-    bArgs.setForcesNewWindow(newWindow);
-    KParts::OpenUrlArguments urlArgs;
-    urlArgs.metaData().insert("SuggestedFileName", it->suggestedFileName());
-    askBrowserToOpenUrl(url, it->mimeType(), urlArgs, bArgs);
-}
 
-void WebEnginePage::requestOpenFileAsTemporary(const QUrl& url, const QString &mimeType, bool newWindow, bool newTab)
-{
     KParts::BrowserArguments bArgs;
     bArgs.setForcesNewWindow(newWindow);
-    bArgs.setNewTab(newTab);
-    KParts::OpenUrlArguments oArgs;
-    oArgs.setMimeType(mimeType);
-    oArgs.metaData().insert("konq-temp-file", "1");
-    emit part()->browserExtension()->openUrlRequest(url, oArgs, bArgs);
+    KParts::OpenUrlArguments args;
+
+    QMimeDatabase db;
+    QMimeType mime = db.mimeTypeForName(item->mimeType());
+    if (!mime.isValid() || mime.isDefault()) {
+        mime = db.mimeTypeForFile(item->suggestedFileName(), QMimeDatabase::MatchExtension);
+    }
+    args.setMimeType(mime.name());
+
+    args.metaData().insert(QStringLiteral("DontSendToDefaultHTMLPart"), QString());
+    args.metaData().insert(QStringLiteral("SuggestedFileName"), item->suggestedFileName());
+    if (requestSave) {
+        //The value doesn't matter
+        args.metaData().insert(QStringLiteral("ForceSave"), QString());
+    }
+
+//TODO KF6: this lamba only exists to reduce code duplication in the two #ifdef
+//branches below. When KF5 compatibility will be removed, cookies will always
+//be managed internally, so remove the #ifdef and the lambda and move its body
+//inside the `if (downloader)`
+    auto requestDownloadAndOpen = [&]() {
+        args.metaData().insert(QStringLiteral("TempFile"), QString());
+        emit downloader->downloadAndOpenUrl(url, item->id(), args, bArgs, true);
+        if (item->state() == QWebEngineDownloadRequest::DownloadRequested) {
+            qCDebug(WEBENGINEPART_LOG()) << "Automatically accepting download for" << item->url() << "This shouldn't happen";
+            item->accept();
+        }
+    };
+//TODO KF6: remove #ifndef and line inside it when compatibility with KF5 isn't needed anymore.
+#ifdef MANAGE_COOKIES_INTERNALLY
+    if (downloader) {
+        requestDownloadAndOpen();
+    } else { //It should never happen
+        qCDebug(WEBENGINEPART_LOG()) << "WebEnginePart for" << part()->url() << "doesn't have a WebEnginePartDownloaderExtension";
+        emit m_part->browserExtension()->openUrlRequest(url, args, bArgs);
+        item->cancel();
+        item->deleteLater();
+    }
+#else
+// blob URLs can't be downloaded by KIO, so use the part to download them even when using KCookieJar
+    if (item->url().scheme() == QStringLiteral("blob") && downloader) {
+        requestDownloadAndOpen();
+    } else {
+        emit m_part->browserExtension()->openUrlRequest(url, args, bArgs);
+        item->cancel();
+        item->deleteLater();
+    }
+#endif
 }
 
 # ifndef REMOTE_DND_NOT_HANDLED_BY_WEBENGINE
@@ -388,10 +467,17 @@ static int errorCodeFromReply(QNetworkReply* reply)
 }
 #endif
 
+#if QT_VERSION_MAJOR < 6
 bool WebEnginePage::certificateError(const QWebEngineCertificateError& ce)
 {
     return WebEnginePartControls::self()->handleCertificateError(ce, this);
 }
+#else
+void WebEnginePage::handleCertificateError(const QWebEngineCertificateError &ce) {
+    WebEnginePartControls::self()->handleCertificateError(ce, this);
+}
+#endif
+
 
 WebEnginePart* WebEnginePage::part() const
 {
@@ -562,7 +648,7 @@ void WebEnginePage::slotGeometryChangeRequested(const QRect & rect)
     // time of its creation, which is always the case in QWebEnginePage::createWindow,
     // then any move operation will seem not to work. That is because the new
     // window will be in maximized mode where moving it will not be possible...
-    if (WebEngineSettings::self()->windowMovePolicy(host) == KParts::HtmlSettingsInterface::JSWindowMoveAllow &&
+    if (WebEngineSettings::self()->windowMovePolicy(host) == HtmlSettingsInterface::JSWindowMoveAllow &&
         (view()->x() != rect.x() || view()->y() != rect.y()))
         emit m_part->browserExtension()->moveTopLevelWidget(rect.x(), rect.y());
 
@@ -583,7 +669,7 @@ void WebEnginePage::slotGeometryChangeRequested(const QRect & rect)
         return;
     }
 
-    if (WebEngineSettings::self()->windowResizePolicy(host) == KParts::HtmlSettingsInterface::JSWindowResizeAllow) {
+    if (WebEngineSettings::self()->windowResizePolicy(host) == HtmlSettingsInterface::JSWindowResizeAllow) {
         //qCDebug(WEBENGINEPART_LOG) << "resizing to " << width << "x" << height;
         emit m_part->browserExtension()->resizeTopLevelWidget(width, height);
     }
@@ -598,7 +684,7 @@ void WebEnginePage::slotGeometryChangeRequested(const QRect & rect)
     if (bottom > sg.bottom())
         moveByY = - bottom + sg.bottom(); // always <0
 
-    if ((moveByX || moveByY) && WebEngineSettings::self()->windowMovePolicy(host) == KParts::HtmlSettingsInterface::JSWindowMoveAllow)
+    if ((moveByX || moveByY) && WebEngineSettings::self()->windowMovePolicy(host) == HtmlSettingsInterface::JSWindowMoveAllow)
         emit m_part->browserExtension()->moveTopLevelWidget(view()->x() + moveByX, view()->y() + moveByY);
 }
 
@@ -758,10 +844,10 @@ void WebEnginePage::setPageJScriptPolicy(const QUrl &url)
     settings()->setAttribute(QWebEngineSettings::JavascriptEnabled,
                              WebEngineSettings::self()->isJavaScriptEnabled(hostname));
 
-    const KParts::HtmlSettingsInterface::JSWindowOpenPolicy policy = WebEngineSettings::self()->windowOpenPolicy(hostname);
+    const HtmlSettingsInterface::JSWindowOpenPolicy policy = WebEngineSettings::self()->windowOpenPolicy(hostname);
     settings()->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows,
-                             (policy != KParts::HtmlSettingsInterface::JSWindowOpenDeny &&
-                              policy != KParts::HtmlSettingsInterface::JSWindowOpenSmart));
+                             (policy != HtmlSettingsInterface::JSWindowOpenDeny &&
+                              policy != HtmlSettingsInterface::JSWindowOpenSmart));
 }
 
 void WebEnginePage::slotAuthenticationRequired(const QUrl &requestUrl, QAuthenticator *auth)
@@ -864,13 +950,13 @@ bool NewWindowPage::acceptNavigationRequest(const QUrl &url, NavigationType type
             if (!part() && !isMainFrame) {
                 return false;
             }
-            const KParts::HtmlSettingsInterface::JSWindowOpenPolicy policy = WebEngineSettings::self()->windowOpenPolicy(reqUrl.host());
+            const HtmlSettingsInterface::JSWindowOpenPolicy policy = WebEngineSettings::self()->windowOpenPolicy(reqUrl.host());
             switch (policy) {
-            case KParts::HtmlSettingsInterface::JSWindowOpenDeny:
+            case HtmlSettingsInterface::JSWindowOpenDeny:
                 // TODO: Implement support for dealing with blocked pop up windows.
                 this->deleteLater();
                 return false;
-            case KParts::HtmlSettingsInterface::JSWindowOpenAsk: {
+            case HtmlSettingsInterface::JSWindowOpenAsk: {
                 const QString message = (reqUrl.isEmpty() ?
                                           i18n("This site is requesting to open a new popup window.\n"
                                                "Do you want to allow this?") :
