@@ -28,11 +28,11 @@
 #include "webhistoryinterface.h"
 #include "webenginewallet.h"
 #include "webengineparterrorschemehandler.h"
-#include "webenginepartcookiejar.h"
 #include "webengineurlrequestinterceptor.h"
 #include "spellcheckermanager.h"
 #include "webenginepartdownloadmanager.h"
 #include "webenginepartcontrols.h"
+#include "profile.h"
 
 #include "ui/searchbar.h"
 #include "ui/passwordbar.h"
@@ -88,14 +88,18 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
              m_statusBarWalletLabel(nullptr),
              m_searchBar(nullptr),
              m_passwordBar(nullptr),
-             m_wallet(nullptr)
+             m_wallet(nullptr),
+             m_downloader(new WebEngineDownloaderExtension(this))
 {
     if (!WebEnginePartControls::self()->isReady()) {
-        WebEnginePartControls::self()->setup(QWebEngineProfile::defaultProfile());
+        WebEnginePartControls::self()->setup(KonqWebEnginePart::Profile::defaultProfile());
     }
 
     connect(WebEnginePartControls::self(), &WebEnginePartControls::userAgentChanged, this, &WebEnginePart::reloadAfterUAChange);
 
+    //Used by KonqInterfaces::DownloaderExtension::downloader()
+    setProperty("DownloaderExtension", QVariant::fromValue(WebEnginePartControls::self()->downloadManager()));
+
     setMetaData(metaData);
 
 #if 0
@@ -123,14 +127,9 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
     // Add status bar extension...
     m_statusBarExtension = new KParts::StatusBarExtension(this);
 
-    // Add a web history interface for storing visited links.
-//    if (!QWebEngineHistoryInterface::defaultInterface())
-//        QWebHistoryInterface::setDefaultInterface(new WebHistoryInterface(this));
-
     // Add text and html extensions...
     new WebEngineTextExtension(this);
     new WebEngineHtmlExtension(this);
-    new WebEngineScriptableExtension(this);
 
 
     // Layout the GUI...
@@ -150,10 +149,6 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
             this, &Part::setWindowCaption);
     connect(m_webView, &QWebEngineView::urlChanged,
             this, &WebEnginePart::slotUrlChanged);
-//    connect(m_webView, SIGNAL(linkMiddleOrCtrlClicked(QUrl)),
-//            this, SLOT(slotLinkMiddleOrCtrlClicked(QUrl)));
-//    connect(m_webView, SIGNAL(selectionClipboardUrlPasted(QUrl,QString)),
-//            this, SLOT(slotSelectionClipboardUrlPasted(QUrl,QString)));
     connect(m_webView, &QWebEngineView::loadFinished,
             this, &WebEnginePart::slotLoadFinished);
 
@@ -256,7 +251,7 @@ void WebEnginePart::initActions()
 
     KCodecAction *codecAction = new KCodecAction( QIcon::fromTheme(QStringLiteral("character-set")), i18n( "Set &Encoding" ), this, true );
     actionCollection()->addAction( QStringLiteral("setEncoding"), codecAction );
-    connect(codecAction, &KCodecAction::codecTriggered, this, &WebEnginePart::slotSetTextEncoding);
+    connect(codecAction, &KCodecAction::codecNameTriggered, this, &WebEnginePart::slotSetTextEncoding);
     action = new QAction(i18n("View Do&cument Source"), this);
     actionCollection()->addAction(QStringLiteral("viewDocumentSource"), action);
     actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_U));
@@ -301,21 +296,7 @@ void WebEnginePart::connectWebEnginePageSignals(WebEnginePage* page)
     connect(page, &QWebEnginePage::loadStarted, this, &WebEnginePart::slotLoadStarted);
     connect(page, &WebEnginePage::loadAborted, this, &WebEnginePart::slotLoadAborted);
     connect(page, &QWebEnginePage::linkHovered, this, &WebEnginePart::slotLinkHovered);
-//    connect(page, SIGNAL(saveFrameStateRequested(QWebFrame*,QWebHistoryItem*)),
-//            this, SLOT(slotSaveFrameState(QWebFrame*,QWebHistoryItem*)));
-//    connect(page, SIGNAL(restoreFrameStateRequested(QWebFrame*)),
-//            this, SLOT(slotRestoreFrameState(QWebFrame*)));
-//    connect(page, SIGNAL(statusBarMessage(QString)),
-//            this, SLOT(slotSetStatusBarText(QString)));
     connect(page, &QWebEnginePage::windowCloseRequested, this, &WebEnginePart::slotWindowCloseRequested);
-//    connect(page, SIGNAL(printRequested(QWebFrame*)),
-//            m_browserExtension, SLOT(slotPrintRequested(QWebFrame*)));
- //   connect(page, SIGNAL(frameCreated(QWebFrame*)),
- //           this, SLOT(slotFrameCreated(QWebFrame*)));
-
-//    connect(m_webView, SIGNAL(linkShiftClicked(QUrl)),
-//            page, SLOT(downloadUrl(QUrl)));
-
     connect(page, &QWebEnginePage::loadProgress, m_browserExtension, &KParts::BrowserExtension::loadingProgress);
     connect(page, &QWebEnginePage::selectionChanged, m_browserExtension, &WebEngineBrowserExtension::updateEditActions);
 //    connect(m_browserExtension, SIGNAL(saveUrl(QUrl)),
@@ -362,7 +343,7 @@ WebEngineWallet* WebEnginePart::wallet() const
 void WebEnginePart::attemptInstallKIOSchemeHandler(const QUrl& url)
 {
      if (KProtocolManager::defaultMimetype(url) == "text/html") { // man:, info:, etc.
-        QWebEngineProfile *prof = QWebEngineProfile::defaultProfile();
+        auto *prof = KonqWebEnginePart::Profile::defaultProfile();
         QByteArray scheme = url.scheme().toUtf8();
         //Qt complains about installing a scheme handler overriding the internal "about" scheme
         if (scheme != "about" && !prof->urlSchemeHandler(scheme)) {
@@ -835,7 +816,7 @@ void WebEnginePart::slotRemoveCachedPasswords()
     updateWalletData(WalletData::HasCachedData, false);
 }
 
-void WebEnginePart::slotSetTextEncoding(QTextCodec * codec)
+void WebEnginePart::slotSetTextEncoding(const QString &codecName)
 {
     // FIXME: The code below that sets the text encoding has been reported not to work.
     if (!page())
@@ -845,16 +826,16 @@ void WebEnginePart::slotSetTextEncoding(QTextCodec * codec)
     if (!localSettings)
         return;
 
-    qCDebug(WEBENGINEPART_LOG) << "Encoding: new=>" << localSettings->defaultTextEncoding() << ", old=>" << codec->name();
+    qCDebug(WEBENGINEPART_LOG) << "Encoding: new=>" << localSettings->defaultTextEncoding() << ", old=>" << codecName;
 
-    localSettings->setDefaultTextEncoding(codec->name());
+    localSettings->setDefaultTextEncoding(codecName);
     page()->triggerAction(QWebEnginePage::Reload);
 }
 
 void WebEnginePart::slotSetStatusBarText(const QString& text)
 {
     const QString host (page() ? page()->url().host() : QString());
-    if (WebEngineSettings::self()->windowStatusPolicy(host) == KParts::HtmlSettingsInterface::JSWindowStatusAllow)
+    if (WebEngineSettings::self()->windowStatusPolicy(host) == HtmlSettingsInterface::JSWindowStatusAllow)
         emit setStatusBarText(text);
 }
 
