@@ -36,6 +36,7 @@
 #include <KIO/OpenUrlJob>
 #include <KParts/BrowserRun>
 #include <KEMailClientLauncherJob>
+#include <KIO/JobUiDelegateFactory>
 
 #include <QBuffer>
 #include <QVariant>
@@ -56,6 +57,8 @@
 
 using Element = KParts::SelectorInterface::Element;
 
+using namespace KonqInterfaces;
+
 // A functor that calls a member function
 template<typename Arg, typename R, typename C>
 struct InvokeWrapper {
@@ -548,7 +551,7 @@ void WebEngineBrowserExtension::slotViewDocumentSource()
     const QUrl pageUrl (view()->url());
     if (pageUrl.isLocalFile()) {
         KIO::OpenUrlJob *job = new KIO::OpenUrlJob(pageUrl, QL1S("text/plain"));
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, view()));
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, view()));
         job->start();
     } else {
         view()->page()->toHtml([this](const QString& html) {
@@ -559,7 +562,7 @@ void WebEngineBrowserExtension::slotViewDocumentSource()
                 tempFile.write(html.toUtf8());
                 tempFile.close();
                 KIO::OpenUrlJob *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(tempFile.fileName()), QL1S("text/plain"));
-                job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, view()));
+                job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, view()));
                 job->setDeleteTemporaryFile(true);
                 job->start();
             }
@@ -858,9 +861,9 @@ void WebEngineBrowserExtension::slotLinkInTop()
 ////
 
 WebEngineTextExtension::WebEngineTextExtension(WebEnginePart* part)
-    : KParts::TextExtension(part)
+    : TextExtension(part)
 {
-    connect(part->view(), &QWebEngineView::selectionChanged, this, &KParts::TextExtension::selectionChanged);
+    connect(part->view(), &QWebEngineView::selectionChanged, this, &TextExtension::selectionChanged);
 }
 
 WebEnginePart* WebEngineTextExtension::part() const
@@ -911,7 +914,7 @@ QString WebEngineTextExtension::completeText(Format format) const
 ////
 
 WebEngineHtmlExtension::WebEngineHtmlExtension(WebEnginePart* part)
-    : KParts::HtmlExtension(part)
+    : HtmlExtension(part)
 {
 }
 
@@ -1016,7 +1019,7 @@ void WebEngineHtmlExtension::querySelectorAsync(const QString& query, KParts::Se
     part()->page()->runJavaScript(fullQuery, QWebEngineScript::ApplicationWorld, internalCallback);
 }
 
-QVariant WebEngineHtmlExtension::htmlSettingsProperty(KParts::HtmlSettingsInterface::HtmlSettingsType type) const
+QVariant WebEngineHtmlExtension::htmlSettingsProperty(HtmlSettingsInterface::HtmlSettingsType type) const
 {
     QWebEngineView* view = part() ? part()->view() : nullptr;
     QWebEnginePage* page = view ? view->page() : nullptr;
@@ -1024,27 +1027,27 @@ QVariant WebEngineHtmlExtension::htmlSettingsProperty(KParts::HtmlSettingsInterf
 
     if (settings) {
         switch (type) {
-        case KParts::HtmlSettingsInterface::AutoLoadImages:
+        case HtmlSettingsInterface::AutoLoadImages:
             return settings->testAttribute(QWebEngineSettings::AutoLoadImages);
-        case KParts::HtmlSettingsInterface::JavaEnabled:
+        case HtmlSettingsInterface::JavaEnabled:
             return false; // settings->testAttribute(QWebEngineSettings::JavaEnabled);
-        case KParts::HtmlSettingsInterface::JavascriptEnabled:
+        case HtmlSettingsInterface::JavascriptEnabled:
             return settings->testAttribute(QWebEngineSettings::JavascriptEnabled);
-        case KParts::HtmlSettingsInterface::PluginsEnabled:
+        case HtmlSettingsInterface::PluginsEnabled:
             return settings->testAttribute(QWebEngineSettings::PluginsEnabled);
-        case KParts::HtmlSettingsInterface::DnsPrefetchEnabled:
+        case HtmlSettingsInterface::DnsPrefetchEnabled:
             return false; //settings->testAttribute(QWebEngineSettings::DnsPrefetchEnabled);
-        case KParts::HtmlSettingsInterface::MetaRefreshEnabled:
+        case HtmlSettingsInterface::MetaRefreshEnabled:
             return view->pageAction(QWebEnginePage::Stop)->isEnabled();
-        case KParts::HtmlSettingsInterface::LocalStorageEnabled:
+        case HtmlSettingsInterface::LocalStorageEnabled:
             return settings->testAttribute(QWebEngineSettings::LocalStorageEnabled);
-        case KParts::HtmlSettingsInterface::OfflineStorageDatabaseEnabled:
+        case HtmlSettingsInterface::OfflineStorageDatabaseEnabled:
             return false; //settings->testAttribute(QWebEngineSettings::OfflineStorageDatabaseEnabled);
-        case KParts::HtmlSettingsInterface::OfflineWebApplicationCacheEnabled:
+        case HtmlSettingsInterface::OfflineWebApplicationCacheEnabled:
             return false ;//settings->testAttribute(QWebEngineSettings::OfflineWebApplicationCacheEnabled);
-        case KParts::HtmlSettingsInterface::PrivateBrowsingEnabled:
+        case HtmlSettingsInterface::PrivateBrowsingEnabled:
             return false; //settings->testAttribute(QWebEngineSettings::PrivateBrowsingEnabled);
-        case KParts::HtmlSettingsInterface::UserDefinedStyleSheetURL:
+        case HtmlSettingsInterface::UserDefinedStyleSheetURL:
             return false; //settings->userStyleSheetUrl();
         default:
             break;
@@ -1054,7 +1057,7 @@ QVariant WebEngineHtmlExtension::htmlSettingsProperty(KParts::HtmlSettingsInterf
     return QVariant();
 }
 
-bool WebEngineHtmlExtension::setHtmlSettingsProperty(KParts::HtmlSettingsInterface::HtmlSettingsType type, const QVariant& value)
+bool WebEngineHtmlExtension::setHtmlSettingsProperty(HtmlSettingsInterface::HtmlSettingsType type, const QVariant& value)
 {
     QWebEngineView* view = part() ? part()->view() : nullptr;
     QWebEnginePage* page = view ? view->page() : nullptr;
@@ -1062,37 +1065,37 @@ bool WebEngineHtmlExtension::setHtmlSettingsProperty(KParts::HtmlSettingsInterfa
 
     if (settings) {
         switch (type) {
-        case KParts::HtmlSettingsInterface::AutoLoadImages:
+        case HtmlSettingsInterface::AutoLoadImages:
             settings->setAttribute(QWebEngineSettings::AutoLoadImages, value.toBool());
             return true;
-        case KParts::HtmlSettingsInterface::JavaEnabled:
+        case HtmlSettingsInterface::JavaEnabled:
             //settings->setAttribute(QWebESettings::JavaEnabled, value.toBool());
             return false;
-        case KParts::HtmlSettingsInterface::JavascriptEnabled:
+        case HtmlSettingsInterface::JavascriptEnabled:
             settings->setAttribute(QWebEngineSettings::JavascriptEnabled, value.toBool());
             return true;
-        case KParts::HtmlSettingsInterface::PluginsEnabled:
+        case HtmlSettingsInterface::PluginsEnabled:
             settings->setAttribute(QWebEngineSettings::PluginsEnabled, value.toBool());
             return true;
-        case KParts::HtmlSettingsInterface::DnsPrefetchEnabled:
+        case HtmlSettingsInterface::DnsPrefetchEnabled:
 //            settings->setAttribute(QWebEngineSettings::DnsPrefetchEnabled, value.toBool());
             return false;
-        case KParts::HtmlSettingsInterface::MetaRefreshEnabled:
+        case HtmlSettingsInterface::MetaRefreshEnabled:
             view->triggerPageAction(QWebEnginePage::Stop);
             return true;
-        case KParts::HtmlSettingsInterface::LocalStorageEnabled:
+        case HtmlSettingsInterface::LocalStorageEnabled:
             settings->setAttribute(QWebEngineSettings::LocalStorageEnabled, value.toBool());
             return false;
-        case KParts::HtmlSettingsInterface::OfflineStorageDatabaseEnabled:
+        case HtmlSettingsInterface::OfflineStorageDatabaseEnabled:
             //settings->setAttribute(QWebEngineSettings::OfflineStorageDatabaseEnabled, value.toBool());
             return false;
-        case KParts::HtmlSettingsInterface::OfflineWebApplicationCacheEnabled:
+        case HtmlSettingsInterface::OfflineWebApplicationCacheEnabled:
             //settings->setAttribute(QWebEngineSettings::OfflineWebApplicationCacheEnabled, value.toBool());
             return false;
-        case KParts::HtmlSettingsInterface::PrivateBrowsingEnabled:
+        case HtmlSettingsInterface::PrivateBrowsingEnabled:
             //settings->setAttribute(QWebEnngineSettings::PrivateBrowsingEnabled, value.toBool());
             return false;
-        case KParts::HtmlSettingsInterface::UserDefinedStyleSheetURL:
+        case HtmlSettingsInterface::UserDefinedStyleSheetURL:
             //qCDebug(WEBENGINEPART_LOG) << "Setting user style sheet for" << page << "to" << value.toUrl();
           //  settings->setUserStyleSheetUrl(value.toUrl());
             return false;
@@ -1109,92 +1112,35 @@ WebEnginePart* WebEngineHtmlExtension::part() const
     return static_cast<WebEnginePart*>(parent());
 }
 
-WebEngineScriptableExtension::WebEngineScriptableExtension(WebEnginePart* part)
-    : ScriptableExtension(part)
+WebEngineDownloaderExtension::WebEngineDownloaderExtension(WebEnginePart* parent) : DownloaderExtension(parent)
 {
 }
 
-QVariant WebEngineScriptableExtension::rootObject()
+WebEngineDownloaderExtension::~WebEngineDownloaderExtension()
 {
-    return QVariant::fromValue(KParts::ScriptableExtension::Object(this, reinterpret_cast<quint64>(this)));
 }
 
-bool WebEngineScriptableExtension::setException (KParts::ScriptableExtension* callerPrincipal, const QString& message)
-{
-    return KParts::ScriptableExtension::setException (callerPrincipal, message);
-}
-
-QVariant WebEngineScriptableExtension::get (KParts::ScriptableExtension* callerPrincipal, quint64 objId, const QString& propName)
-{
-    //qCDebug(WEBENGINEPART_LOG) << "caller:" << callerPrincipal << "id:" << objId << "propName:" << propName;
-    return callerPrincipal->get (nullptr, objId, propName);
-}
-
-bool WebEngineScriptableExtension::put (KParts::ScriptableExtension* callerPrincipal, quint64 objId, const QString& propName, const QVariant& value)
-{
-    return KParts::ScriptableExtension::put (callerPrincipal, objId, propName, value);
-}
-
-static QVariant exception(const char* msg)
-{
-    qCWarning(WEBENGINEPART_LOG) << msg;
-    return QVariant::fromValue(KParts::ScriptableExtension::Exception(QString::fromLatin1(msg)));
-}
-
-QVariant WebEngineScriptableExtension::evaluateScript (KParts::ScriptableExtension* callerPrincipal,
-                                                     quint64 contextObjectId,
-                                                     const QString& code,
-                                                     KParts::ScriptableExtension::ScriptLanguage lang)
-{
-    Q_UNUSED(contextObjectId);
-    Q_UNUSED(code)
-    //qCDebug(WEBENGINEPART_LOG) << "principal:" << callerPrincipal << "id:" << contextObjectId << "language:" << lang << "code:" << code;
-
-    if (lang != ECMAScript)
-        return exception("unsupported language");
-
-
-    KParts::ReadOnlyPart* part = callerPrincipal ? qobject_cast<KParts::ReadOnlyPart*>(callerPrincipal->parent()) : nullptr;
-   // QWebFrame* frame = part ? qobject_cast<QWebFrame*>(part->parent()) : 0;
-   // if (!frame)
-        return exception("failed to resolve principal");
-#if 0
-    QVariant result (frame->evaluateJavaScript(code));
-
-    if (result.type() == QVariant::Map) {
-        const QVariantMap map (result.toMap());
-        for (QVariantMap::const_iterator it = map.constBegin(), itEnd = map.constEnd(); it != itEnd; ++it) {
-            callerPrincipal->put(callerPrincipal, 0, it.key(), it.value());
-        }
-    } else {
-        const QString propName(code.contains(QLatin1String("__nsplugin")) ? QLatin1String("__nsplugin") : QString());
-        callerPrincipal->put(callerPrincipal, 0, propName, result.toString());
-    }
-
-    return QVariant::fromValue(ScriptableExtension::Null());
-#endif
-}
-
-bool WebEngineScriptableExtension::isScriptLanguageSupported (KParts::ScriptableExtension::ScriptLanguage lang) const
-{
-    return (lang == KParts::ScriptableExtension::ECMAScript);
-}
-
-QVariant WebEngineScriptableExtension::encloserForKid (KParts::ScriptableExtension* kid)
-{
-#if 0
-    KParts::ReadOnlyPart* part = kid ? qobject_cast<KParts::ReadOnlyPart*>(kid->parent()) : 0;
-    QWebFrame* frame = part ? qobject_cast<QWebFrame*>(part->parent()) : 0;
-    if (frame) {
-        return QVariant::fromValue(KParts::ScriptableExtension::Object(kid, reinterpret_cast<quint64>(kid)));
-    }
-#endif
-
-    return QVariant::fromValue(ScriptableExtension::Null());
-}
-
-WebEnginePart* WebEngineScriptableExtension::part()
+KParts::ReadOnlyPart* WebEngineDownloaderExtension::part() const
 {
     return qobject_cast<WebEnginePart*>(parent());
 }
 
+void WebEngineDownloaderExtension::addDownloadRequest(QWebEngineDownloadRequest* req)
+{
+    QUrl url = req->url();
+    m_downloadRequests.insert(url, req);
+    auto removeRequest = [this, url] (QObject *obj) {m_downloadRequests.remove(url, dynamic_cast<QWebEngineDownloadRequest*>(obj));};
+    connect(req, &QWebEngineDownloadItem::destroyed, this, removeRequest);
+}
+
+KonqInterfaces::DownloaderJob* WebEngineDownloaderExtension::downloadJob(const QUrl& url, quint32 id, QObject* parent)
+{
+    auto items = m_downloadRequests.values(url);
+    if (items.isEmpty()) {
+        return nullptr;
+    }
+    auto it = std::find_if(items.constBegin(), items.constEnd(), [id](QWebEngineDownloadItem* it){return it->id() == id;});
+    //If no job with the given ID is found, return the last one, which is the first created
+    QWebEngineDownloadItem *item = it != items.constEnd() ? *it : items.last();
+    return new WebEngineDownloadJob(item, parent);
+}
