@@ -11,16 +11,18 @@
 
 #include "kwebenginepartlib_export.h"
 
+#include "interfaces/downloaderextension.h"
+#include "qtwebengine6compat.h"
+
 #include <QPointer>
 
 #include <KParts/BrowserExtension>
-#include <KParts/TextExtension>
-#include <KParts/HtmlExtension>
-#include <KParts/HtmlSettingsInterface>
-#include <KParts/ScriptableExtension>
 #include <KParts/SelectorInterface>
 
 #include <asyncselectorinterface.h>
+#include <htmlextension.h>
+#include <htmlsettingsinterface.h>
+#include <textextension.h>
 
 class QUrl;
 class WebEnginePart;
@@ -121,7 +123,7 @@ private:
  * @internal
  * Implements the TextExtension interface
  */
-class WebEngineTextExtension : public KParts::TextExtension
+class WebEngineTextExtension : public TextExtension
 {
     Q_OBJECT
 public:
@@ -139,13 +141,13 @@ private:
  * @internal
  * Implements the HtmlExtension interface
  */
-class WebEngineHtmlExtension : public KParts::HtmlExtension,
+class WebEngineHtmlExtension : public HtmlExtension,
                              public AsyncSelectorInterface,
-                             public KParts::HtmlSettingsInterface
+                             public HtmlSettingsInterface
 {
     Q_OBJECT
     Q_INTERFACES(AsyncSelectorInterface)
-    Q_INTERFACES(KParts::HtmlSettingsInterface)
+    Q_INTERFACES(HtmlSettingsInterface)
 
 public:
     WebEngineHtmlExtension(WebEnginePart* part);
@@ -198,31 +200,18 @@ private:
     static KParts::SelectorInterface::Element jsonToElement(const QJsonObject &obj);
 };
 
-class WebEngineScriptableExtension : public KParts::ScriptableExtension
+class WebEngineDownloaderExtension : public KonqInterfaces::DownloaderExtension
 {
-  Q_OBJECT
-
+    Q_OBJECT
 public:
-    WebEngineScriptableExtension(WebEnginePart* part);
-
-    QVariant rootObject() override;
-
-    QVariant get(ScriptableExtension* callerPrincipal, quint64 objId, const QString& propName) override;
-
-    bool put(ScriptableExtension* callerPrincipal, quint64 objId, const QString& propName, const QVariant& value) override;
-
-    bool setException(ScriptableExtension* callerPrincipal, const QString& message) override;
-
-    QVariant evaluateScript(ScriptableExtension* callerPrincipal,
-                                    quint64 contextObjectId,
-                                    const QString& code,
-                                    ScriptLanguage language = ECMAScript) override;
-
-    bool isScriptLanguageSupported(ScriptLanguage lang) const override;
+    WebEngineDownloaderExtension(WebEnginePart *parent);
+    ~WebEngineDownloaderExtension();
+    KonqInterfaces::DownloaderJob* downloadJob(const QUrl &url, quint32 id, QObject *parent=nullptr) override;
+    void addDownloadRequest(QWebEngineDownloadRequest *req);
+    KParts::ReadOnlyPart* part() const override;
 
 private:
-     QVariant encloserForKid(KParts::ScriptableExtension* kid) override;
-     WebEnginePart* part();
+    QMultiHash<QUrl, QWebEngineDownloadRequest*> m_downloadRequests;
 };
 
 #endif // WEBENGINEPART_EXT_H
